@@ -98,9 +98,14 @@ class WeakNetworkConfig(object):
 
     def _connect_ios(self, device):
         # 发送自动点击弹窗配置
+        self.bundle_id = self._stf.find_ios_bundle_id(device['serial'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        logger.info("changewifi app bundle_id:{}".format(self.bundle_id))
+        if self.bundle_id is None:
+            logger.error("not found changewifi bundle_id:{}".format(self.bundle_id))
+            return None
         self._stf.watch_alert(device['wda_url'])
-        self._stf.stop_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-        self._stf.launch_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        self._stf.stop_ios_app(device['wda_url'], self.bundle_id)
+        self._stf.launch_ios_app(device['wda_url'], self.bundle_id)
         timeout = 2 * 60
         t1 = time.time()
         while True:
@@ -115,6 +120,8 @@ class WeakNetworkConfig(object):
                     return device_ip
                 else:
                     time.sleep(1)
+            else:
+                time.sleep(1)
 
     def _disconnect_android(self, serial):
         ret = self._stf.toggleAndroidWifi(serial, "3", self._wifi_name, self._wifi_password)
@@ -167,59 +174,4 @@ class WeakNetworkConfig(object):
             else:
                 return False
         except Exception as e:
-            return False
-
-
-if __name__ == '__main__':
-    token = "24dc77b46c7542a28cc74888aed16d15fc0d0d3077ed48e5b68956e2668eef27"
-    sft_url = "http://10.12.35.2:8086"
-    config = WeakNetworkConfig(stf_url=sft_url, sft_token=token)
-    json_config = {
-        "up": {
-            "loss": {
-                "percentage": "30",
-                "correlation": 0
-            },
-            "rate": "1024",
-            "delay": {
-                "delay": 0,
-                "jitter": 0,
-                "correlation": 0
-            },
-            "reorder": {
-                "gap": 0,
-                "percentage": 0,
-                "correlation": 0
-            },
-            "corruption": {
-                "percentage": 0,
-                "correlation": 0
-            },
-            "iptables_options": []
-        },
-        "down": {
-            "loss": {
-                "percentage": "30",
-                "correlation": 0
-            },
-            "rate": "1024",
-            "delay": {
-                "delay": 0,
-                "jitter": 0,
-                "correlation": 0
-            },
-            "reorder": {
-                "gap": 0,
-                "percentage": 0,
-                "correlation": 0
-            },
-            "corruption": {
-                "percentage": 0,
-                "correlation": 0
-            },
-            "iptables_options": []
-        }
-    }
-    config.set_auth("192.168.0.11")
-    flag = config.set_net_config("192.168.0.11", json_config)
-    print(flag)
+            return False
\ No newline at end of file
